<?php

    class Date_Within_Window_Condition extends Reactor_Condition
    {
        protected $tpl = 'date_within_window.php';
        protected $name = 'Date is within window';
		
		public static $registration = array(
			CONDITION_NAME => 'Date within window',
			CONDITION_CATEGORY => 'Time',
			CONDITION_DESCRIPTION => 'Checks if the current date is within a given window.',
			CONDITION_AUTHOR => 'Scott Wilkerson, Mike Guthrie, Nagios Enterprises, LLC',
			CONDITION_VERSION => '1.0',
			CONDITION_DATE => '02/22/2013', //Last version update
			CONDITION_AUTHLEVEL => 0,  // 0 - everyone | 1 - Admin only
			CONDITION_TYPE => 'core', //core | user. core modules can't be deleted
			CONDITION_META => array('time'),	//Misc information	
		); 				
		
        protected $fields = array(
            'start_day' => array(
                'label' => 'start day',
                'validate' => 'trim|required|numeric|xss_clean|less_than[31]|greater_than[0]',
            ),
            'end_day' => array(
                'label' => 'end day',
                'validate' => 'trim|required|numeric|xss_clean|less_than[31]|greater_than[0]',
            ),
            'start_month' => array(
                'label' => 'start month',
                'validate' => 'trim|required|numeric|xss_clean|less_than[13]|greater_than[0]',
            ),			
            'end_month' => array(
                'label' => 'end month',
                'validate' => 'trim|required|numeric|xss_clean|less_than[13]|greater_than[0]',
            ),
            'start_year' => array(
                'label' => 'start year',
                'validate' => 'trim|required|numeric|xss_clean|greater_than[1970]',
            ),			
            'end_year' => array(
                'label' => 'end year',
                'validate' => 'trim|required|numeric|xss_clean|greater_than[1970]',
            ),
        );

        
        public function get_label()
        {

            if($params = $this->get_params()) {
                if(array_key_exists('start_day', $params) &&
                   array_key_exists('end_day', $params) &&
				   array_key_exists('start_month', $params) &&
                   array_key_exists('end_month', $params) &&
				   array_key_exists('start_year', $params) &&
                   array_key_exists('end_year', $params)  ) 
				   {
                        return sprintf('The date is between %d-%d-%d and %d-%d-%d',
                            $params['start_day'], $params['start_month'], $params['start_year'],
                            $params['end_day'], $params['end_month'],$params['end_year']);
                   }
            }
            return parent::get_label();
       
        }
        public function run($context)
        {
            $this->set_context($context);
            $params = $this->get_params();

            $ts_start = strtotime(sprintf("%d-%d-%d 00:00", $params['start_day'], $params['start_month'], $params['start_year']));
            $ts_end = strtotime(sprintf("%d-%d-%d 24:00", $params['end_day'], $params['end_month'], $params['end_year']));
            $now = time();
			$this->set_context_var('time', $now);
            $this->set_result($now >= $ts_start && $now <= $ts_end);
        }
    }
